# XX精灵

## 1 介绍
```bash
基于pynput实现的XX精灵
1. 监听键盘鼠标操作并录制为脚本文件
2. 执行录制的脚本文件回放键盘鼠标操作
```


## 2 功能介绍
#### 2.1 录制
###### 2.1.0 界面预览
![](https://oscimg.oschina.net/oscnet/up-b476be130a1d1eea814476244b0e53e21f0.png)
###### 2.1.1 脚本名称
```bash
本次录制存储的脚本名称, 名称不存在则新建, 已存在则覆盖
```
###### 2.1.2 鼠标轨迹
```bash
是否记录鼠标轨迹, 默认开启
```
###### 2.1.3 鼠标间隔
```bash
开启鼠标轨迹后, 轨迹坐标间隔超过x像素时才会记录到脚本中, 数值越小轨迹越平滑, 相应的记录的脚本体积也越大
```
###### 2.1.4 录制热键
```bash
使用键盘控制开始录制和停止录制, 按下该键跟鼠标点击按钮起到相同的效果
```
###### 2.1.5 窗口隐藏
```bash
录制开始时最小化窗口, 录制结束后窗口恢复
```
#### 2.2 回放
###### 2.2.0 界面预览
![](https://oscimg.oschina.net/oscnet/up-1641384eedd99e9bc0ab52200e1006f9e21.png)
###### 2.2.1 脚本名称
```bash
下拉选择一个要回放的脚本, 如果没有请先录制 
```
###### 2.2.2 重复次数
```bash
重复执行脚本的次数, 默认为0, 即不重复执行 
```
###### 2.2.3 重复间隔
```bash
重复次数大于0时, 执行完一次脚本延迟x秒后重复下一次执行
```
###### 2.2.4 回放热键
```bash
使用键盘控制开始回放和停止回放, 按下该键跟鼠标点击按钮起到相同的效果
```
###### 2.2.5 窗口隐藏
```bash
回放开始时最小化窗口, 回放结束后窗口恢复
```
